Sign inSign up

essentialkaos/sslcli

By essentialkaos

•Updated 1 day ago

Pretty awesome command-line client for public SSLLabs API

Image
Developer tools
1

4.7K

essentialkaos/sslcli repository overview

GitHub Actions Status

Usage demo⁠ • Installation⁠ • Feature list⁠ • Usage⁠ • Build Status⁠ • Contributing⁠ • Terms of Use⁠ • License⁠


sslcli is command-line client for SSLLabs⁠ public API.

IMPORTANT: Currently, SSLLabs API doesn't provide same info as SSLLabs website.

⁠Usage demo

demo

⁠Installation
⁠From source

To build the SSLScan Client from scratch, make sure you have a working Go 1.17+ workspace (instructions⁠), then:

go install github.com/essentialkaos/sslcli@latest
⁠From ESSENTIAL KAOS Public Repository⁠
sudo yum install -y https://yum.kaos.st/get/$(uname -r).rpm
sudo yum install yo
⁠Prebuilt binaries

You can download prebuilt binaries for Linux and macOS from EK Apps Repository⁠:

bash <(curl -fsSL https://apps.kaos.st/get) sslcli
⁠Docker Image

The latest version of sslcli also available as Docker image on Docker Hub⁠ and GitHub Container Registry⁠:

docker pull essentialkaos/sslcli:latest
docker run --rm -it essentialkaos/sslcli:latest mydomain.com

or

docker pull ghcr.io/essentialkaos/sslcli:latest
docker run --rm -it ghcr.io/essentialkaos/sslcli:latest mydomain.com
⁠Feature list
  • Superb UI
  • Output very similar to SSLLabs website output
  • Checking many hosts at once
  • Checking hosts defined in the file
  • Check resumption
  • JSON/XML/YAML/Text output for usage in third party scripts
⁠Usage
Usage: sslcli {options} host…

Options

  --format, -f text|json|yaml|xml    Output result in different formats
  --detailed, -d                     Show detailed info for each endpoint
  --ignore-mismatch, -i              Proceed with assessments on certificate mismatch
  --avoid-cache, -c                  Disable cache usage
  --public, -p                       Publish results on sslscan.com
  --perfect, -P                      Return non-zero exit code if not A+
  --max-left, -M duration            Check expiry date (num + d/w/m/y)
  --notify, -n                       Notify when check is done
  --quiet, -q                        Don't show any output
  --no-color, -nc                    Disable colors in output
  --help, -h                         Show this help message
  --version, -v                      Show version

Examples

  sslcli google.com
  Check google.com

  sslcli -P google.com
  Check google.com and return zero exit code only if result is perfect (A+)

  sslcli -p -c google.com
  Check google.com, publish results, disable cache usage

  sslcli -M 3m -q google.com
  Check google.com in quiet mode and return error if cert expire in 3 months

  sslcli hosts.txt
  Check all hosts defined in hosts.txt file

⁠Build Status
BranchStatus
masterCI
developCI
⁠Contributing

Before contributing to this project please read our Contributing Guidelines⁠.

⁠Terms of Use

This project is not affiliated with SSL Labs and not officially supported by SSL Labs. Before using this package please read Qualys SSL Labs Terms of Use⁠.

Also you should:

  • Only inspect sites and servers whose owners have given you permission to do so;
  • Be clear that this tool works by sending assessment requests to remote SSL Labs servers and that this information will be shared with them.
⁠License

Apache License, Version 2.0⁠

Tag summary

Content type

Image

Digest

sha256:6f35997a6…

Size

11.5 MB

Last updated

1 day ago

docker pull essentialkaos/sslcli